@@ -163,12 +163,14 @@ class Queue(OrchestratorHTTP):
 
     def _format_specific_content(self, queue_name, sp_content, priority="Low", progress="New", reference=None, batch_id=None):
         ran_uuid = str(uuid4())
+        sp_content.update({"ReferenceID": ran_uuid})
+        sp_content.update({"BatchID": batch_id})
         formatted_sp_content = {
             "Name": queue_name,
             "Priority": priority,
             "SpecificContent": sp_content,
             "Progress": progress,
-            "ReferenceID": ran_uuid
+
 
         }
         try:
